# Sermatec Solar Inverter
This repository contains local API documentation for the Sermatec solar inverter and communication scripts.

## Index
- [`DEVELOPMENT.md`](docs/DEVELOPMENT.md): protocol reverse-engineering guide.
- [`PROTOCOL.md`](docs/PROTOCOL.md): protocol documentation.
- [`sermatec.py`](src/sermatec_inverter/sermatec.py): communication script.

## License
The project is licensed under the MIT License. (C) Ondrej Golasowski